@@ -7,7 +7,7 @@
 
 #include <OpenImageIO/imagebufalgo.h>
 
-OIIO_NAMESPACE_BEGIN
+OIIO_NAMESPACE_3_1_BEGIN
 
 namespace ImageBufAlgo {
 
@@ -33,4 +33,4 @@ mosaic_uint8(ImageBuf& dst, const ImageBuf& src, int x_offset, int y_offset,
 
 }  // namespace ImageBufAlgo
 
-OIIO_NAMESPACE_END
+OIIO_NAMESPACE_3_1_END
